@@ -51,12 +51,14 @@
 	newdat <- as.data.frame(newdat)
 
   	## Delete hidden column(s) unless showHidden=TRUE
-  	if(showHidden==TRUE)   {} else
-  	{if(is.null(decode$metaData$id)) {} else
-  		{hide.ind <- which(refdf$hide==TRUE)
-  		newdat <- newdat[,-hide.ind]
-		refdf <- refdf[-hide.ind,]
-		cnames <- cnames[-hide.ind]}}
+      if(showHidden==TRUE)   {} else {
+            if(is.null(decode$metaData$id)) {} else {
+            hide.ind <- which(refdf$hide==TRUE); if(length(hide.ind)>0){
+            newdat <- newdat[,-hide.ind]
+            refdf <- refdf[-hide.ind,]
+            cnames <- cnames[-hide.ind]} else {}
+            }
+      }
 
 	## Set mode for multiple columns of data (this also removes list factor)
 	if(is.null(dim(newdat))==FALSE) 
